==> activity-usercenter-api-0.2.24-sources.jar: cn/com/duiba/tuia/activity/usercenter/api/dto/ConfigUrl.java <==
package cn.com.duiba.tuia.activity.usercenter.api.dto;

public class ConfigUrl {

  /**
   * 一级怪物
   */
  public static final int MONSTER1 = 1;
  /**
   * 二级怪物
   */
  public static final int MONSTER2 = 2;
  /**
   * 三级怪物
   */
  public static final int MONSTER3 = 3;
  /**
   * 四级怪物
   */
  public static final int MONSTER4 = 4;
  /**
   * 五级怪物
   */
  public static final int MONSTER5 = 5;

  /**
   * 六级怪物
   */
  public static final int MONSTER6 = 6;
  /**
   * banner
   */
  public static final int BANNER = 200;
  /**
   * 炮筒一
   */
  public static final int BARREL1 = 300;
  /**
   * 炮筒二
   */
  public static final int BARREL2 = 301;
  /**
   * 炮筒三
   */
  public static final int BARREL3 = 302;

  /**
   * 背景图
   */
  public static final int BACKGROUND1 = 400;

  /**
   * 图片类型
   */
  private Integer type;

  /**
   * 图片文案
   */
  private String imgText;

  /**
   * 图片地址
   */
  private String imgUrl;

  /**
   * 下载地址
   */
  private String downloadUrl;

  private String showUrl;

  /**
   * 图片宽度
   */
  private Integer width;

  /**
   * 图片高度
   */
  private Integer height;

  public Integer getType() {
    return type;
  }

  public void setType(Integer type) {
    this.type = type;
  }

  public String getImgText() {
    return imgText;
  }

  public void setImgText(String imgText) {
    this.imgText = imgText;
  }

  public String getImgUrl() {
    return imgUrl;
  }

  public void setImgUrl(String imgUrl) {
    this.imgUrl = imgUrl;
  }

  public String getDownloadUrl() {
    return downloadUrl;
  }

  public void setDownloadUrl(String downloadUrl) {
    this.downloadUrl = downloadUrl;
  }

  public String getShowUrl() {
    return showUrl;
  }

  public void setShowUrl(String showUrl) {
    this.showUrl = showUrl;
  }

  public Integer getWidth() {
    return width;
  }

  public void setWidth(Integer width) {
    this.width = width;
  }

  public Integer getHeight() {
    return height;
  }

  public void setHeight(Integer height) {
    this.height = height;
  }
}

==> activity-usercenter-api-0.3.11-20220228.015644-1-sources.jar: cn/com/duiba/tuia/activity/usercenter/api/dto/ConfigUrl.java <==
package cn.com.duiba.tuia.activity.usercenter.api.dto;

import java.io.Serializable;

public class ConfigUrl implements Serializable {

  /**
   * 一级怪物
   */
  public static final int MONSTER1 = 1;
  /**
   * 二级怪物
   */
  public static final int MONSTER2 = 2;
  /**
   * 三级怪物
   */
  public static final int MONSTER3 = 3;
  /**
   * 四级怪物
   */
  public static final int MONSTER4 = 4;
  /**
   * 五级怪物
   */
  public static final int MONSTER5 = 5;

  /**
   * 六级怪物
   */
  public static final int MONSTER6 = 6;
  /**
   * banner
   */
  public static final int BANNER = 200;
  /**
   * 炮筒一
   */
  public static final int BARREL1 = 300;
  /**
   * 炮筒二
   */
  public static final int BARREL2 = 301;
  /**
   * 炮筒三
   */
  public static final int BARREL3 = 302;

  /**
   * 背景图
   */
  public static final int BACKGROUND1 = 400;

  /**
   * 图片类型
   */
  private Integer type;

  /**
   * 图片文案
   */
  private String imgText;

  /**
   * 图片地址
   */
  private String imgUrl;

  /**
   * 下载地址
   */
  private String downloadUrl;

  private String showUrl;

  /**
   * 图片宽度
   */
  private Integer width;

  /**
   * 图片高度
   */
  private Integer height;

  public Integer getType() {
    return type;
  }

  public void setType(Integer type) {
    this.type = type;
  }

  public String getImgText() {
    return imgText;
  }

  public void setImgText(String imgText) {
    this.imgText = imgText;
  }

  public String getImgUrl() {
    return imgUrl;
  }

  public void setImgUrl(String imgUrl) {
    this.imgUrl = imgUrl;
  }

  public String getDownloadUrl() {
    return downloadUrl;
  }

  public void setDownloadUrl(String downloadUrl) {
    this.downloadUrl = downloadUrl;
  }

  public String getShowUrl() {
    return showUrl;
  }

  public void setShowUrl(String showUrl) {
    this.showUrl = showUrl;
  }

  public Integer getWidth() {
    return width;
  }

  public void setWidth(Integer width) {
    this.width = width;
  }

  public Integer getHeight() {
    return height;
  }

  public void setHeight(Integer height) {
    this.height = height;
  }
}
